@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2007-2018  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2007-2022  Ruby-GNOME Project Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,19 @@
  *  MA  02110-1301  USA
  */
 
-#ifndef __RBGPRIVATE_H__
-#define __RBGPRIVATE_H__
+#pragma once
+
+/*
+ * CentOS 7: GLib 2.50
+ * AlmaLinux 8: GLib 2.56
+ * AlmaLinux 9: GLib 2.68
+ * Ubuntu 18.04: GLib 2.56
+ * Ubuntu 20.04: GLib 2.64
+ * Ubuntu 22.04: GLib 2.72
+ */
+#define GLIB_VERSION_MIN_REQUIRED GLIB_VERSION_2_50
+
+#define G_LOG_DOMAIN "Ruby/GLib2"
 
 #include "rbgobject.h"
 
@@ -35,6 +46,10 @@
 #  define G_VALUE_INIT { 0, { { 0 } } }
 #endif
 
+#ifndef RUBY_TYPED_FROZEN_SHAREABLE
+#  define RUBY_TYPED_FROZEN_SHAREABLE 0
+#endif
+
 G_BEGIN_DECLS
 
 typedef struct {
@@ -51,7 +66,8 @@ typedef struct {
     GType type;
 } boxed_holder;
 
-G_GNUC_INTERNAL extern GStaticPrivate rg_polling_key;
+G_GNUC_INTERNAL extern GPrivate rg_polling_key;
+G_GNUC_INTERNAL extern rb_encoding *rbg_filename_encoding;
 
 extern VALUE rbgobj_cEnum;
 extern VALUE rbgobj_cFlags;
@@ -114,6 +130,15 @@ G_GNUC_INTERNAL void rg_enum_add_constants(VALUE mod, GType enum_type, const gch
 G_GNUC_INTERNAL void rg_flags_add_constants(VALUE mod, GType flags_type, const gchar *strip_prefix);
 G_GNUC_INTERNAL char *rg_obj_constant_lookup(const char *name);
 
+G_GNUC_INTERNAL VALUE rbg_gc_marker_new(void);
+G_GNUC_INTERNAL void rbg_gc_marker_guard(VALUE rb_gc_marker,
+                                         VALUE rb_object);
+G_GNUC_INTERNAL void rbg_gc_marker_unguard(VALUE rb_gc_marker,
+                                           VALUE rb_object);
+G_GNUC_INTERNAL void rbg_gc_marker_unguard_all(VALUE rb_gc_marker);
+
+G_GNUC_INTERNAL void Init_glib_gc(void);
+
 G_GNUC_INTERNAL void Init_gutil(void);
 G_GNUC_INTERNAL void Init_gutil_callback(void);
 G_GNUC_INTERNAL void Init_glib_gettext(void);
@@ -164,7 +189,6 @@ G_GNUC_INTERNAL void Init_gobject_gvalue(void);
 G_GNUC_INTERNAL void Init_gobject_gvaluetypes(void);
 G_GNUC_INTERNAL void Init_gobject_gboxed(void);
 G_GNUC_INTERNAL void Init_gobject_gstrv(void);
-G_GNUC_INTERNAL void Init_gobject_value_array(void);
 G_GNUC_INTERNAL void Init_gobject_genumflags(void);
 G_GNUC_INTERNAL void Init_gobject_genums(void);
 G_GNUC_INTERNAL void Init_gobject_gflags(void);
@@ -178,5 +202,3 @@ G_GNUC_INTERNAL void Init_gobject_gtypemodule(void);
 G_GNUC_INTERNAL void Init_gobject_gbinding(void);
 
 G_END_DECLS
-
-#endif
